aboutsummaryrefslogtreecommitdiffstats
path: root/params/config.go
diff options
context:
space:
mode:
Diffstat (limited to 'params/config.go')
-rw-r--r--params/config.go25
1 files changed, 15 insertions, 10 deletions
diff --git a/params/config.go b/params/config.go
index 18579666b..345f6394a 100644
--- a/params/config.go
+++ b/params/config.go
@@ -77,17 +77,22 @@ var (
},
}
// AllProtocolChanges contains every protocol change (EIPs)
// introduced and accepted by the Ethereum core developers.
//
- // This configuration is intentionally not using keyed fields.
- // This configuration must *always* have all forks enabled, which
- // means that all fields must be set at all times. This forces
- // anyone adding flags to the config to also have to set these
- // fields.
- AllProtocolChanges = &ChainConfig{big.NewInt(1337), big.NewInt(0), nil, false, big.NewInt(0), common.Hash{}, big.NewInt(0), big.NewInt(0), big.NewInt(0), new(EthashConfig), nil}
- TestChainConfig = &ChainConfig{big.NewInt(1), big.NewInt(0), nil, false, big.NewInt(0), common.Hash{}, big.NewInt(0), big.NewInt(0), big.NewInt(0), new(EthashConfig), nil}
- TestRules = TestChainConfig.Rules(new(big.Int))
+ // This configuration is intentionally not using keyed fields to force anyone
+ // adding flags to the config to also have to set these fields.
+ AllEthashProtocolChanges = &ChainConfig{big.NewInt(1337), big.NewInt(0), nil, false, big.NewInt(0), common.Hash{}, big.NewInt(0), big.NewInt(0), big.NewInt(0), new(EthashConfig), nil}
+
+ // AllCliqueProtocolChanges contains every protocol change (EIPs) introduced
+ // and accepted by the Ethereum core developers into the Clique consensus.
+ //
+ // This configuration is intentionally not using keyed fields to force anyone
+ // adding flags to the config to also have to set these fields.
+ AllCliqueProtocolChanges = &ChainConfig{big.NewInt(1337), big.NewInt(0), nil, false, big.NewInt(0), common.Hash{}, big.NewInt(0), big.NewInt(0), big.NewInt(0), nil, &CliqueConfig{Period: 0, Epoch: 30000}}
+
+ TestChainConfig = &ChainConfig{big.NewInt(1), big.NewInt(0), nil, false, big.NewInt(0), common.Hash{}, big.NewInt(0), big.NewInt(0), big.NewInt(0), new(EthashConfig), nil}
+ TestRules = TestChainConfig.Rules(new(big.Int))
)
// ChainConfig is the core config which determines the blockchain settings.
@@ -77,17 +77,22 @@ var (
},
}
- // AllProtocolChanges contains every protocol change (EIPs)
- // introduced and accepted by the Ethereum core developers.
+ // AllEthashProtocolChanges contains every protocol change (EIPs) introduced
+ // and accepted by the Ethereum core developers into the Ethash consensus.
//